@@ -15,6 +15,8 @@ use Carp;
     
     enum 'Form', [qw(quarter half triangular logarithmic parabola)];
     
+    our %gencmd_form = ('quarter' => 'q','half' => 'h','triangular' => 't','logarithmic' => 'l','parabola' => 'p');
+    
     has 'in' => (
         is => 'rw',
         isa => 'Num',
@@ -30,10 +32,9 @@ use Carp;
         isa => 'Form',
     );
     
-    sub soxi {
-        my $self = shift;        
-        my %form_soxi_table = ('quarter' => 'q','half' => 'h','triangular' => 't','logarithmic' => 'l','parabola' => 'p');
-        my $ret = sprintf("%s %s %s 0 %s",$self->fx,$form_soxi_table{$self->form},$self->in,$self->out);
+    sub gencmd {
+        my $self = shift;
+        my $ret = sprintf("%s %s %s 0 %s",$self->fx,$Narwhal::Effect::Fade::gencmd_form{$self->form},$self->in,$self->out);
         return($ret);
     }
 }
