@@ -10,7 +10,7 @@ use Carp;
     use Moose;
     use Moose::Util::TypeConstraints;
     
-    enum 'FM', [qw(pluck)];
+    enum 'FM', [qw(pluck sine square triangle noise sawtooth trapezium exp pinknoise whitenoise brownnoise tpdfnoise)];
     
     has 'fm' => (
         is => 'rw',
@@ -28,10 +28,6 @@ use Carp;
         my @classparts = split(/::/,ref($self));
         $self->fm(lc($classparts[-1]));
     }
-    
-    sub soxi {
-        return("");
-    }
 }
 
 1;
\ No newline at end of file
