@@ -45,13 +45,11 @@ use Carp;
     },
   );
   
-  sub soxi {
+  sub gencmd {
     my $self = shift;
-    my $synth = shift;
-    my @classname = split(/::/,ref($synth));
-    my $ret = sprintf("%s %s %s %s %s %s %s",$classname[-1],$synth->length,$self->fm,$self->note,$self->sustain,$self->tone1,$self->tone2);
+    my $ret = sprintf("%s %s %s %s %s",$self->fm,$self->note,$self->sustain,$self->tone1,$self->tone2);
     return($ret);
   }
 }
 
-1;
\ No newline at end of file
+1;
